pub struct PollState(/* private fields */);Implementations
Sourceimpl PollState
impl PollState
Sourcepub const ERROR: Self
pub const ERROR: Self
There is a pending error that can be read using TcpState::clear_error.
Sourcepub const RECV_CLOSED: Self
pub const RECV_CLOSED: Self
The connection has been closed for receiving. This is not mutually exclusive with
READABLE (even if it’s closed for receiving, there may still be buffered data to
read). Some possible causes are:
- Received a FIN packet.
- Sent or received a RST packet.
- TCP was closed.
Sourcepub const SEND_CLOSED: Self
pub const SEND_CLOSED: Self
The connection has been closed for sending. This should be mutually exclusive with
WRITABLE (there would be no point in writing data if it’s closed for sending). Some
possible causes are:
- Sent a FIN packet.
- Sent or received a RST packet.
- TCP was
shutdown()for writing. - TCP was closed.
Sourcepub const READY_TO_ACCEPT: Self
pub const READY_TO_ACCEPT: Self
A listening socket has a new incoming connection that can be accepted.
Sourcepub const CONNECTING: Self
pub const CONNECTING: Self
Connection is in the process of opening. More specifically this means that it is in either the “syn-sent” or “syn-received” states.
Sourcepub const CONNECTED: Self
pub const CONNECTED: Self
A connection has previously been attempted and was either successful or unsuccessful (it may or may not have reached the “established” state). The connection may be established, timed out, closing, half-closed, closed, etc. This does not include connection attempts that are in progress (“syn-sent” or “syn-received” states).
Sourcepub const CLOSED: Self
pub const CLOSED: Self
TCP is fully closed (in the “closed” state). This may not be set immediately after a
close() call, for example if close() was called while in the “established” state,
and now is in the “fin-wait-1” state. This does not include the initial state (we don’t
consider a new TCP to be “closed”).
Sourceimpl PollState
impl PollState
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.